@@ -1,6 +1,6 @@
-import time
+import re
 
-import pysftp
+import paramiko
 
 from vlcishared.utils.interfaces import ConnectionInterface
 
@@ -15,22 +15,38 @@ class SFTPClient(ConnectionInterface):
         self.port = port
         self.username = username
         self.password = password
-        self.cnopts = pysftp.CnOpts()
-        self.cnopts.hostkeys = None
+        self.transport = None
         self.sftp = None
 
     def connect(self) -> None:
         """Intenta conectarse al servidor configurado en la instanciación"""
         try:
-            self.sftp = pysftp.Connection(host=self.host, port=self.port, username=self.username, password=self.password, cnopts=self.cnopts)
+            self.transport = paramiko.Transport((self.host, self.port))
+            self.transport.connect(username=self.username, password=self.password)
+            self.sftp = paramiko.SFTPClient.from_transport(self.transport)
         except Exception as e:
             raise ConnectionRefusedError(f"Conexión fallida: {str(e)}")
 
-    def list(self, remote_path: str) -> list:
+    def download(self, remote_path: str, local_path: str, pattern: str):
+        '''Descarga en local los ficheros del directorio remoto que coincidan con el patrón indicado"'''
+        try:
+            file_list = self.list_matching_files(remote_path, pattern)
+            if len(file_list) > 0:
+                for file_name in file_list:
+                    self.sftp.get(f"{remote_path}/{file_name}", f"{local_path}/{file_name}")
+        except Exception as e:
+            raise ConnectionAbortedError(f"Descarga fallida: {str(e)}")
+
+    def list_matching_files(self, remote_path: str, pattern: str) -> list:
+        """Devuelve una lista de ficheros en el directorio indicado que coincidan con el patrón indicado."""
+        remote_files = self.list_all_files(remote_path)
+        matching_files = [f for f in remote_files if re.fullmatch(pattern, f)]
+        return matching_files
+
+    def list_all_files(self, remote_path: str) -> list:
         """Devuelve una lista con los ficheros en el directorio indicado"""
         try:
-            with self.sftp.cd(remote_path):
-                remote_files = self.sftp.listdir()
+            remote_files = self.sftp.listdir(remote_path)
             return remote_files
         except Exception as e:
             raise ConnectionAbortedError(f"Fallo al listar los archivos: {str(e)}")
@@ -38,22 +54,13 @@ class SFTPClient(ConnectionInterface):
     def list_sorted_date_modification(self, remote_path: str) -> list:
         """Devuelve una lista con los ficheros en el directorio indicado, ordenados por fecha de modificación"""
         try:
-            with self.sftp.cd(remote_path):
-                remote_files_attr = self.sftp.listdir_attr()
+            remote_files_attr = self.sftp.listdir_attr(remote_path)
             remote_files_attr_sorted = sorted(remote_files_attr, key=lambda attr: attr.st_mtime)
             remote_files_sorted = [attr.filename for attr in remote_files_attr_sorted]
             return remote_files_sorted
         except Exception as e:
             raise ConnectionAbortedError(f"Fallo al listar los archivos: {str(e)}")
 
-    def download(self, remote_path: str, local_path: str, file_name: str):
-        '''Descarga el fichero recibido como parámetro y
-        lo guarda en el "local_path"'''
-        try:
-            self.sftp.get(f"{remote_path}/{file_name}", f"{local_path}/{file_name}")
-        except Exception as e:
-            raise ConnectionAbortedError(f"Descarga fallida: {str(e)}")
-
     def move(self, remote_origin_path: str, destiny_path: str, file_name: str):
         """Mueve el fichero recibido como parámetro de
         la carpeta origen a la carpeta destino"""
@@ -67,6 +74,8 @@ class SFTPClient(ConnectionInterface):
         if self.sftp:
             self.sftp.close()
             print(f"Conexión a {self.host} cerrada.")
+        if self.transport:
+            self.transport.close()
 
     def upload(self, local_file: str, remote_path: str):
         """Sube el fichero indicado desde la máquina local al servidor SFTP"""
